@@ -27,6 +27,7 @@ import (
 	"github.com/apache/answer/internal/service/file_record"
 	"github.com/apache/answer/internal/service/service_config"
 	"github.com/apache/answer/internal/service/siteinfo_common"
+	"github.com/apache/answer/internal/service/user_admin"
 	"github.com/robfig/cron/v3"
 	"github.com/segmentfault/pacman/log"
 )
@@ -36,6 +37,7 @@ type ScheduledTaskManager struct {
 	siteInfoService   siteinfo_common.SiteInfoCommonService
 	questionService   *content.QuestionService
 	fileRecordService *file_record.FileRecordService
+	userAdminService  *user_admin.UserAdminService
 	serviceConfig     *service_config.ServiceConfig
 }
 
@@ -44,12 +46,14 @@ func NewScheduledTaskManager(
 	siteInfoService siteinfo_common.SiteInfoCommonService,
 	questionService *content.QuestionService,
 	fileRecordService *file_record.FileRecordService,
+	userAdminService *user_admin.UserAdminService,
 	serviceConfig *service_config.ServiceConfig,
 ) *ScheduledTaskManager {
 	manager := &ScheduledTaskManager{
 		siteInfoService:   siteInfoService,
 		questionService:   questionService,
 		fileRecordService: fileRecordService,
+		userAdminService:  userAdminService,
 		serviceConfig:     serviceConfig,
 	}
 	return manager
@@ -78,6 +82,19 @@ func (s *ScheduledTaskManager) Run() {
 		log.Error(err)
 	}
 
+	// Check for expired user suspensions every 10 minutes
+	_, err = c.AddFunc("*/10 * * * *", func() {
+		ctx := context.Background()
+		log.Infof("checking expired user suspensions")
+		err := s.userAdminService.CheckAndUnsuspendExpiredUsers(ctx)
+		if err != nil {
+			log.Errorf("failed to check expired user suspensions: %v", err)
+		}
+	})
+	if err != nil {
+		log.Error(err)
+	}
+
 	if s.serviceConfig.CleanUpUploads {
 		log.Infof("clean up uploads cron enabled")
 
