@@ -147,7 +147,9 @@ func Migrate(debug bool, dbConf *data.Database, cacheConf *data.CacheConf, upgra
 		fmt.Println("new database failed: ", err.Error())
 		return err
 	}
-	defer engine.Close()
+	defer func() {
+		_ = engine.Close()
+	}()
 
 	currentDBVersion, err := GetCurrentDBVersion(engine)
 	if err != nil {
