@@ -26,15 +26,16 @@ import (
 
 	"github.com/apache/answer/internal/repo/export"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func Test_emailRepo_VerifyCode(t *testing.T) {
 	emailRepo := export.NewEmailRepo(testDataSource)
 	code, content := "1111", "{\"source_type\":\"\",\"e_mail\":\"\",\"user_id\":\"1\",\"skip_validation_latest_code\":false}"
 	err := emailRepo.SetCode(context.TODO(), "1", code, content, time.Minute)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	verifyContent, err := emailRepo.VerifyCode(context.TODO(), code)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, content, verifyContent)
 }
