@@ -31,7 +31,6 @@ import {
 } from '@/stores';
 import {
   Header,
-  Footer,
   Toast,
   Customize,
   CustomizeTheme,
@@ -210,7 +209,6 @@ const Layout: FC = () => {
           revalidateOnFocus: false,
         }}>
         <Header />
-        {/* eslint-disable-next-line jsx-a11y/click-events-have-key-events */}
         <div className="position-relative page-wrap d-flex flex-column flex-fill">
           {httpStatusCode ? (
             <HttpErrorContent httpCode={httpStatusCode} />
@@ -219,7 +217,6 @@ const Layout: FC = () => {
           )}
         </div>
         <Toast msg={toastMsg} variant={variant} onClose={closeToast} />
-        <Footer />
         <Customize />
         <LoginToContinueModal visible={showLoginToContinueModal} />
         <BadgeModal
